@@ -9,13 +9,8 @@
 #pragma once
 
 #include <QSortFilterProxyModel>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-template<typename T>
-class QVector;
-#else
 template<typename T>
 class QList;
-#endif
 
 namespace Akonadi
 {
@@ -36,12 +31,12 @@ public:
       Returns a vector containing the visible columns. If the vector is empty, all
       columns are visible.
     */
-    Q_REQUIRED_RESULT QVector<int> visbileColumns() const;
+    [[nodiscard]] QList<int> visbileColumns() const;
 
     /**
       Convenience function. Has the same effect as:
       @code
-      setVisibleColumns( QVector<int>() << column );
+      setVisibleColumns( QList<int>() << column );
       @endcode
       @param column the column to set as visible
       @see setVisbileColumns
@@ -52,12 +47,12 @@ public:
       Change the visible columns. Pass an empty vector to make all columns visible.
       @param visibleColumns the vector changing visible columns
      */
-    void setVisibleColumns(const QVector<int> &visibleColumns);
+    void setVisibleColumns(const QList<int> &visibleColumns);
 
 protected:
     bool filterAcceptsColumn(int column, const QModelIndex &parent) const override;
 
 private:
-    QVector<int> m_visibleColumns;
+    QList<int> m_visibleColumns;
 };
 }
